package javax.xml.ws;

import org.w3c.dom.Element;
import java.util.Map;
import java.util.concurrent.Executor;
import javax.xml.transform.Source;
import java.util.List;
import javax.xml.ws.spi.http.HttpContext;
import javax.xml.ws.spi.Provider;

public abstract class Endpoint
{
    public static final String WSDL_SERVICE = "javax.xml.ws.wsdl.service";
    public static final String WSDL_PORT = "javax.xml.ws.wsdl.port";
    
    public Endpoint() {
    }
    
    public static Endpoint create(Object implementor) {
        return create(null, implementor);
    }
    
    public static Endpoint create(Object implementor, WebServiceFeature... features) {
        return create(null, implementor, features);
    }
    
    public static Endpoint create(String bindingId, Object implementor) {
        return Provider.provider().createEndpoint(bindingId, implementor);
    }
    
    public static Endpoint create(String bindingId, Object implementor, WebServiceFeature... features) {
        return Provider.provider().createEndpoint(bindingId, implementor, features);
    }
    
    public abstract Binding getBinding();
    
    public abstract Object getImplementor();
    
    public abstract void publish(String p0);
    
    public static Endpoint publish(String address, Object implementor) {
        return Provider.provider().createAndPublishEndpoint(address, implementor);
    }
    
    public static Endpoint publish(String address, Object implementor, WebServiceFeature... features) {
        return Provider.provider().createAndPublishEndpoint(address, implementor, features);
    }
    
    public abstract void publish(Object p0);
    
    public void publish(HttpContext serverContext) {
        throw new UnsupportedOperationException("JAX-WS 2.2 implementation must override this default behaviour.");
    }
    
    public abstract void stop();
    
    public abstract boolean isPublished();
    
    public abstract List<Source> getMetadata();
    
    public abstract void setMetadata(List<Source> p0);
    
    public abstract Executor getExecutor();
    
    public abstract void setExecutor(Executor p0);
    
    public abstract Map<String, Object> getProperties();
    
    public abstract void setProperties(Map<String, Object> p0);
    
    public abstract EndpointReference getEndpointReference(Element... p0);
    
    public abstract <T extends EndpointReference> T getEndpointReference(Class<T> p0, Element... p1);
    
    public void setEndpointContext(EndpointContext ctxt) {
        throw new UnsupportedOperationException("JAX-WS 2.2 implementation must override this default behaviour.");
    }
}
